/* Declinazione di responsabilità. 
I file rilasciati in formato testo sono provvisti anche dei programmi di importazione per STATA, SAS e R. 
L'Istat non garantisce che le funzioni contenute nei suddetti programmi siano esenti da errore e non si assume alcuna responsabilità sull’output ottenuto dal loro utilizzo.                 */
%macro grabpath;
%qsubstr(%sysget(SAS_EXECFILEPATH),1,%length(%sysget(SAS_EXECFILEPATH))-%length(%sysget(SAS_EXECFILEname)))
%mend grabpath;
%let path = %grabpath;
%let nomeFile =ISTAT_MFR_VV_Microdati_2020_Individui_ESEMPIO_STRUTTURA_FILE.txt;
LIBNAME ISTAT "&path";
DATA ISTAT.VV_A2020_Individui;

INFILE "&path&nomeFile" DLM='09'x  LRECL=32767 TRUNCOVER FIRSTOBS=2 IGNOREDOSEOF;
INPUT 
tr : $2.   /*  tipo record */
mese : $2.   /*  mese di riferimento dei dati */
annrif : $4.   /*  anno di riferimento dei dati */
progind : $5.   /*  Numero d'ordine progressivo individuale sull'anno */
sesso : $1.   /*  sesso */
eta5 : $2.   /*  Classi di eta' in anni compiuti */
staciv : $1.   /*  stato civile */
citt : $1.   /*  cittadinanza */
reg : $3.   /*  regione di residenza */
rip : $1.   /*  ripartizione geografica di residenza */
istr : $2.   /*  titolo di studio piu' alto conseguito */
condogg : $2.   /*  condizione professionale oggettiva */
posiz : $2.   /*  posizione nella professione */
ateco10 : $2.   /*  settore di attivita' economica */
cond : $2.   /*  condizione professionale soggettiva */
ORARIO : $1.   /*  tipo di orario di lavoro */
RAPP : $1.   /*  tipo di rapporto di lavoro */
CODPROF : $1.   /*  codifica della professione lavorativa (Grandi gruppi) */
novac : $2.   /*  motivo per cui l'individuo non ha effettuato vacanze nel mese */
lavat :2.   /*  numero totale viaggi di lavoro abituali nel mese */
noxlat :2.   /*  numero totale di notti per viaggi di lavoro abituali nel mese */
vacat :2.   /*  numero totale viaggi di vacanza abituali nel mese */
noxvat :2.   /*  numero totale di notti per viaggi di vacanza abituali nel mese */
IESC : $1.   /*  presenza escursioni effettuate dall'individuo nel mese */
INESC :2.   /*  numero escursioni effettuate dall'individuo nel mese */
ivia : $1.   /*  presenza viaggi effettuati dall'individuo nel mese */
invia :2.   /*  numero viaggi effettuati dall'individuo nel mese */
ilav : $1.   /*  presenza viaggi di lavoro effettuati dall'individuo nel mese */
inlav :2.   /*  numero viaggi di lavoro effettuati dall'individuo nel mese */
ivac : $1.   /*  presenza viaggi di vacanza effettuati dall'individuo nel mese */
invac :2.   /*  numero viaggi di vacanza effettuati dall'individuo nel mese */
ibreve : $1.   /*  presenza viaggi di vacanza di 1-3 notti effettuati dall'individuo nel mese */
inbreve :2.   /*  numero viaggi di vacanza di 1-3 notti effettuati dall'individuo nel mese */
ilunga : $1.   /*  presenza viaggi di vacanza di 4 o piu' notti effettuati dall'individuo nel mese */
inlunga :2.   /*  numero viaggi di vacanza di 4 o piu' notti effettuati dall'individuo nel mese */
W :19.7   /*  coefficiente di riporto per le stime di viaggi, escursioni e individui (turisti e non turisti) nel mese medio del trimestre */
COEV :19.7   /*  coefficiente di riporto per il calcolo dell'ammontare dei viaggi (abituali e non abituali) ed escursioni nel mese, nel trimestre e nell'anno */
TRIM : $2.   /*  trimestre di riferimento dei dati */
DOMINIO : $1.   /*  tipologia socio-demografica del comune di residenza */
ncomp : $2.   /*  numero componenti della famiglia di fatto dell'intervista iniziale */
pnasc : $1.   /*  paese di nascita */
;
LABEL 
tr = "tipo record"
mese = "mese di riferimento dei dati"
annrif = "anno di riferimento dei dati"
progind = "Numero d'ordine progressivo individuale sull'anno"
sesso = "sesso"
eta5 = "Classi di eta' in anni compiuti"
staciv = "stato civile"
citt = "cittadinanza"
reg = "regione di residenza"
rip = "ripartizione geografica di residenza"
istr = "titolo di studio piu' alto conseguito"
condogg = "condizione professionale oggettiva"
posiz = "posizione nella professione"
ateco10 = "settore di attivita' economica"
cond = "condizione professionale soggettiva"
ORARIO = "tipo di orario di lavoro"
RAPP = "tipo di rapporto di lavoro"
CODPROF = "codifica della professione lavorativa (Grandi gruppi)"
novac = "motivo per cui l'individuo non ha effettuato vacanze nel mese"
lavat = "numero totale viaggi di lavoro abituali nel mese"
noxlat = "numero totale di notti per viaggi di lavoro abituali nel mese"
vacat = "numero totale viaggi di vacanza abituali nel mese"
noxvat = "numero totale di notti per viaggi di vacanza abituali nel mese"
IESC = "presenza escursioni effettuate dall'individuo nel mese"
INESC = "numero escursioni effettuate dall'individuo nel mese"
ivia = "presenza viaggi effettuati dall'individuo nel mese"
invia = "numero viaggi effettuati dall'individuo nel mese"
ilav = "presenza viaggi di lavoro effettuati dall'individuo nel mese"
inlav = "numero viaggi di lavoro effettuati dall'individuo nel mese"
ivac = "presenza viaggi di vacanza effettuati dall'individuo nel mese"
invac = "numero viaggi di vacanza effettuati dall'individuo nel mese"
ibreve = "presenza viaggi di vacanza di 1-3 notti effettuati dall'individuo nel mese"
inbreve = "numero viaggi di vacanza di 1-3 notti effettuati dall'individuo nel mese"
ilunga = "presenza viaggi di vacanza di 4 o piu' notti effettuati dall'individuo nel mese"
inlunga = "numero viaggi di vacanza di 4 o piu' notti effettuati dall'individuo nel mese"
W = "coefficiente di riporto per le stime di viaggi, escursioni e individui (turisti e non turisti) nel mese medio del trimestre"
COEV = "coefficiente di riporto per il calcolo dell'ammontare dei viaggi (abituali e non abituali) ed escursioni nel mese, nel trimestre e nell'anno"
TRIM = "trimestre di riferimento dei dati"
DOMINIO = "tipologia socio-demografica del comune di residenza"
ncomp = "numero componenti della famiglia di fatto dell'intervista iniziale"
pnasc = "paese di nascita"
;
RUN;
PROC FORMAT;
VALUE $tr0F /* tr */
"02" = "Record individuale"
"03" = "Record viaggi"
"04" = "Record escursioni"
;
VALUE $ses4F /* sesso */
"1" = "Maschi"
"2" = "Femmine"
;
VALUE $eta5F /* eta5 */
"01" = "<=5 anni"
"02" = "6-14 anni"
"03" = "15-17 anni"
"04" = "18-24 anni"
"05" = "25-29 anni"
"06" = "30-34 anni"
"07" = "35-39 anni"
"08" = "40-44 anni"
"09" = "45-49 anni"
"10" = "50-54 anni"
"11" = "55-59 anni"
"12" = "60-64 anni"
"13" = "65-69 anni"
"14" = "70-74 anni"
"15" = ">=75 anni"
;
VALUE $sta6F /* staciv */
"1" = "Celibe/nubile"
"2" = "Coniugato"
"3" = "Separato di fatto"
"4" = "Separato legalmente"
"5" = "Divorziato"
"6" = "Vedovo"
;
VALUE $cit7F /* citt */
"1" = "Italiana"
"2" = "Estera"
;
VALUE $reg8F /* reg */
"010" = "Piemonte"
"020" = "Valle d'Aosta/Vallee' d'Aoste"
"030" = "Lombardia"
"040" = "Trentino A.Adige/Sudtirol"
"050" = "Veneto"
"060" = "Friuli-Venezia Giulia"
"070" = "Liguria"
"080" = "Emilia-Romagna"
"090" = "Toscana"
"100" = "Umbria"
"110" = "Marche"
"120" = "Lazio"
"130" = "Abruzzo"
"140" = "Molise"
"150" = "Campania"
"160" = "Puglia"
"170" = "Basilicata"
"180" = "Calabria"
"190" = "Sicilia"
"200" = "Sardegna"
;
VALUE $rip9F /* rip */
"1" = "Nord-ovest"
"2" = "Nord-est"
"3" = "Centro"
"4" = "Sud"
"5" = "Isole"
;
VALUE $ist10F /* istr */
"01" = "Nessun titolo"
"02" = "Licenza elementare"
"03" = "Licenza media (licenza di avviamento professionale"
"04" = "Dipl. di qualif prof di scuola second di II grado di 2-3 anni,che non permette iscriz univ"
"05" = "Dipl. di istr second sup che permette accesso universita"
"06" = "Dipl. di Accademia (Belle Arti,arte drammatica,Danza),Ist Sup Industrie Artistiche,Conserv di musica,Ist Musicale Pareggiato-vecchio ord.to"
"07" = "Dipl. universitario di due/tre anni, Scuola diretta a fini speciali,altro diploma terziario non universitario"
"08" = "Laurea di I livello - nuovo ordinamento (3 anni)"
"09" = "Laurea - vecchio ordinamento (4/6 anni)"
"10" = "Laurea spec/magistrale a ciclo unico - nuovo ordinamento (corsi di 5/6 anni)"
"11" = "Laurea spec/magistrale - nuovo ordinamento (corsi di II liv di 2 anni)"
"13" = "Dottorato di ricerca/diploma accademico di formazione alla ricerca"
"15" = "Certificato di spec.ne tecnica superiore IFTS"
"16" = "Dipl di tecnico superiore ITS (corsi biennali)"
"17" = "Dipl accad di Alta Formazione Artistica, Musicale e Coreutica (AFAM) di I livello"
"18" = "Dipl accad di Alta Formazione Artistica, Musicale e Coreutica (AFAM) di II livello"
"19" = "Master univ I liv/Dipl accad perfez.to o Master I liv/Diploma accad spec.ne I liv"
"20" = "Master univ II liv/ Dip accad perfez.to o Master di II livello/ Dipl acc spec II livello"
"21" = "Dipl di specializzazione univ"
"22" = "Attestato IeFP di qualifica professionale triennale (operatore,corso trien)/dipl prof IeFP di tecnico(4.to anno)"
;
VALUE $con11F /* condogg */
"01" = "Occupato"
"02" = "In cerca di occupazione"
"03" = "Inattivo"
;
VALUE $pos12F /* posiz */
"01" = "Dirigente"
"02" = "Quadro"
"03" = "Impiegato"
"04" = "Operaio"
"05" = "Apprendista"
"06" = "Lavorante a domicilio per conto d'imprese"
"07" = "Imprenditore"
"08" = "Libero professionista"
"09" = "Lavoratore in proprio"
"10" = "Socio di cooperativa"
"11" = "Coadiuvante nell'azienda di un familiare"
"12" = "Collaboratore coordinato e continuativo (con o senza progetto)"
"13" = "Prestatore d'opera occasionale"
;
VALUE $ate13F /* ateco10 */
"01" = "Agricoltura, caccia e pesca"
"02" = "Industria"
"03" = "Costruzioni"
"04" = "Commercio, trasporto, magazzinaggio, alberghi, ristoranti"
"05" = "Informazione e comunicazione"
"06" = "Attivita' finanziarie"
"07" = "Attivita' immobiliari"
"08" = "Attivita' professionali, scientifiche, attivita' amministrative, servizi di supporto"
"09" = "Pubblica amministrazione, Difesa, Istruzione, Sanita', altri servizi sociali"
"10" = "Altri servizi"
;
VALUE $con14F /* cond */
"01" = "Occupato"
"02" = "In cerca di prima occupazione"
"03" = "In cerca di nuova occupazione"
"04" = "Casalinga"
"05" = "Studente"
"06" = "Persona ritirata dal lavoro"
"07" = "In altra condizione"
;
VALUE $ORA15F /* ORARIO */
"1" = "A tempo pieno"
"2" = "A tempo parziale"
;
VALUE $RAP16F /* RAPP */
"1" = "A tempo determinato"
"2" = "A tempo indeterminato"
;
VALUE $COD17F /* CODPROF */
"1" = "LEGISLATORI, IMPRENDITORI E ALTA DIRIGENZA"
"2" = "PROFESSIONI INTELLETTUALI, SCIENTIFICHE E DI ELEVATA SPECIALIZZAZIONE"
"3" = "PROFESSIONI TECNICHE"
"4" = "PROFESSIONI ESECUTIVE NEL LAVORO D'UFFICIO"
"5" = "PROFESSIONI QUALIFICATE NELLE ATTIVITA' COMMERCIALI E NEI SERVIZI"
"6" = "ARTIGIANI, OPERAI SPECIALIZZATI E AGRICOLTORI"
"7" = "CONDUTTORI DI IMPIANTI, OPERAI DI MACCHINARI FISSI E MOBILI E CONDUCENTI DI VEICOLI"
"8" = "PROFESSIONI NON QUALIFICATE"
"9" = "FORZE ARMATE"
;
VALUE $nov18F /* novac */
"01" = "Motivi economici"
"02" = "Motivi di lavoro,studio,familiari"
"03" = "Mancanza di abitudine"
"04" = "Emergenza sanitaria"
"05" = "Altri motivi (inclusi motivi di salute)"
"99" = "Non sa, non risponde"
;
VALUE $IES23F /* IESC */
"0" = "Nessuna escursione dell'individuo"
"1" = "Almeno un'escursione dell'individuo"
;
VALUE $ivi25F /* ivia */
"0" = "Nessun viaggio dell'individuo"
"1" = "Almeno un viaggio dell'individuo"
;
VALUE $ila27F /* ilav */
"0" = "Nessun viaggio di lavoro dell'individuo"
"1" = "Almeno un viaggio di lavoro dell'individuo"
;
VALUE $iva29F /* ivac */
"0" = "Nessun viaggio di vacanza dell'individuo"
"1" = "Almeno un viaggio di vacanza dell'individuo"
;
VALUE $ibr31F /* ibreve */
"0" = "Nessun viaggio di vacanza 1-3 notti dell'individuo"
"1" = "Almeno un viaggio di vacanza 1-3 notti dell'individuo"
;
VALUE $ilu33F /* ilunga */
"0" = "Nessun viaggio di vacanza lunga dell'individuo"
"1" = "Almeno un viaggio di vacanza lunga dell'individuo"
;
VALUE $TRI37F /* TRIM */
"01" = "Gennaio-Marzo"
"02" = "Aprile-Giugno"
"03" = "Luglio-Settembre"
"04" = "Ottobre-Dicembre"
;
VALUE $DOM38F /* DOMINIO */
"1" = "Comuni centro dell'area metropolitana"
"2" = "Comuni periferia dell'area metropolitana e comuni con 50.001 ab. e piu'"
"3" = "Altri comuni fino a 50.000 ab."
;
VALUE $nco39F /* ncomp */
"1" = "1 componente"
"2" = "2 componenti"
"3" = "3 componenti"
"4" = "4 componenti"
"5" = "5 componenti"
"6" = "6 o piu' componenti"
;
VALUE $pna40F /* pnasc */
"1" = "Italia"
"2" = "Estero"
;
format tr $tr0F.;
format sesso $ses4F.;
format eta5 $eta5F.;
format staciv $sta6F.;
format citt $cit7F.;
format reg $reg8F.;
format rip $rip9F.;
format istr $ist10F.;
format condogg $con11F.;
format posiz $pos12F.;
format ateco10 $ate13F.;
format cond $con14F.;
format ORARIO $ORA15F.;
format RAPP $RAP16F.;
format CODPROF $COD17F.;
format novac $nov18F.;
format IESC $IES23F.;
format ivia $ivi25F.;
format ilav $ila27F.;
format ivac $iva29F.;
format ibreve $ibr31F.;
format ilunga $ilu33F.;
format TRIM $TRI37F.;
format DOMINIO $DOM38F.;
format ncomp $nco39F.;
format pnasc $pna40F.;
RUN;
